pub(in worldgen::feature) struct UpdateFlags(u16);Expand description
Flags that control how a block update is processed.
Tuple Fields
0: u16Implementations
Sourceimpl UpdateFlags
impl UpdateFlags
pub const UPDATE_NEIGHBORS: UpdateFlags
pub const UPDATE_CLIENTS: UpdateFlags
pub const UPDATE_INVISIBLE: UpdateFlags
pub const UPDATE_IMMEDIATE: UpdateFlags
pub const UPDATE_KNOWN_SHAPE: UpdateFlags
pub const UPDATE_SUPPRESS_DROPS: UpdateFlags
pub const UPDATE_MOVE_BY_PISTON: UpdateFlags
pub const UPDATE_SKIP_SHAPE_UPDATE_ON_WIRE: UpdateFlags
pub const UPDATE_SKIP_BLOCK_ENTITY_SIDEEFFECTS: UpdateFlags
pub const UPDATE_SKIP_ON_PLACE: UpdateFlags
pub const UPDATE_NONE: UpdateFlags
pub const UPDATE_ALL: UpdateFlags
pub const UPDATE_ALL_IMMEDIATE: UpdateFlags
Sourceimpl UpdateFlags
impl UpdateFlags
Sourcepub const fn empty() -> UpdateFlags
pub const fn empty() -> UpdateFlags
Get a flags value with all bits unset.
Sourcepub const fn all() -> UpdateFlags
pub const fn all() -> UpdateFlags
Get a flags value with all known bits set.
Sourcepub const fn bits(&self) -> u16
pub const fn bits(&self) -> u16
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u16) -> Option<UpdateFlags>
pub const fn from_bits(bits: u16) -> Option<UpdateFlags>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u16) -> UpdateFlags
pub const fn from_bits_truncate(bits: u16) -> UpdateFlags
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u16) -> UpdateFlags
pub const fn from_bits_retain(bits: u16) -> UpdateFlags
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<UpdateFlags>
pub fn from_name(name: &str) -> Option<UpdateFlags>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: UpdateFlags) -> bool
pub const fn intersects(&self, other: UpdateFlags) -> bool
Whether any set bits in other are also set in self.
Sourcepub const fn contains(&self, other: UpdateFlags) -> bool
pub const fn contains(&self, other: UpdateFlags) -> bool
Whether all set bits in other are also set in self.
Sourcepub fn insert(&mut self, other: UpdateFlags)
pub fn insert(&mut self, other: UpdateFlags)
The bitwise or (|) of the bits in self and other.
Sourcepub fn remove(&mut self, other: UpdateFlags)
pub fn remove(&mut self, other: UpdateFlags)
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: UpdateFlags)
pub fn toggle(&mut self, other: UpdateFlags)
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub fn set(&mut self, other: UpdateFlags, value: bool)
pub fn set(&mut self, other: UpdateFlags, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: UpdateFlags) -> UpdateFlags
pub const fn intersection(self, other: UpdateFlags) -> UpdateFlags
The bitwise and (&) of the bits in self and other.
Sourcepub const fn union(self, other: UpdateFlags) -> UpdateFlags
pub const fn union(self, other: UpdateFlags) -> UpdateFlags
The bitwise or (|) of the bits in self and other.
Sourcepub const fn difference(self, other: UpdateFlags) -> UpdateFlags
pub const fn difference(self, other: UpdateFlags) -> UpdateFlags
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: UpdateFlags) -> UpdateFlags
pub const fn symmetric_difference(self, other: UpdateFlags) -> UpdateFlags
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub const fn complement(self) -> UpdateFlags
pub const fn complement(self) -> UpdateFlags
The bitwise negation (!) of the bits in self, truncating the result.
Sourceimpl UpdateFlags
impl UpdateFlags
Sourcepub const fn iter(&self) -> Iter<UpdateFlags> ⓘ
pub const fn iter(&self) -> Iter<UpdateFlags> ⓘ
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<UpdateFlags> ⓘ
pub const fn iter_names(&self) -> IterNames<UpdateFlags> ⓘ
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.